<?php

namespace Ems\Repository;

use Doctrine\ORM\EntityManager;
use Doctrine\DBAL\Connection;

class CertisignRepository {
    /** @var Connection */
    protected $connection;

    public function __construct(
        EntityManager $entityManager
    ) {
        $this->connection = $entityManager->getConnection();
    }

    public function get(
        int $nrOrg,
        int $nrIntegracao
    ) {
        $sql = <<<SQL
            SELECT *
            FROM GPE_INTELETRDIGIT
            WHERE
                NRINTELETRDIGIT = :P_NRINTELETRDIGIT AND
                NRORG = :P_NRORG
SQL;

        $params = [
            'P_NRINTELETRDIGIT' => $nrIntegracao,
            'P_NRORG' => $nrOrg,
        ];

        $stmt = $this->connection->prepare($sql);
        $stmt->execute($params);
        $result = $stmt->fetch();

        return $result;
    }

    public function deleteIntegracao(
        int $nrOrg,
        int $nrIntegracao
    ) {
        $sql = <<<SQL
            DELETE FROM GPE_INTELETRDIGIT
            WHERE
                NRINTELETRDIGIT = :P_NRINTELETRDIGIT AND
                NRORG = :P_NRORG
SQL;

        $params = [
            'P_NRINTELETRDIGIT' => $nrIntegracao,
            'P_NRORG' => $nrOrg,
        ];

        $stmt = $this->connection->prepare($sql);
        $stmt->execute($params);
    }

    public function setDocumentAsRejected(
        array $params
    ) {
        $sql = <<<SQL
            UPDATE GPE_INTELETRDIGIT
            SET
                IDSTATUS = 'R',
                DTREJEICAO = SYSDATE,
                DSREJEICAO = :P_DSREJEICAO
            WHERE
                NRPARCNEGOCIO = :P_NRPARCNEGOCIO AND
                DSIDDOCUMENTO = :P_IDDOCUMENTO AND
                NRORG = :P_NRORG
SQL;

        $stmt = $this->connection->prepare($sql);
        $stmt->execute($params);
    }

    public function setDocumentAsSigned(
        array $params
    ) {
        $sql = <<<SQL
            UPDATE GPE_INTELETRDIGIT
            SET
                DTASSINATURA = SYSDATE,
                IDSTATUS = 'A'
            WHERE
                NRPARCNEGOCIO = :P_NRPARCNEGOCIO AND
                DSIDDOCUMENTO = :P_IDDOCUMENTO AND
                NRORG = :P_NRORG
SQL;

        $stmt = $this->connection->prepare($sql);
        $stmt->execute($params);
    }

    public function insertIntegracao(
        array $params
    ) {
        $sql = <<<SQL
            INSERT INTO GPE_INTELETRDIGIT (
                NRORG,              NRINTELETRDIGIT,    NRPARCNEGOCIO,
                NRTIPODOCUMENTO,    NRCATEGDOCUMENTO,   IDSTATUS,
                DSIDDOCUMENTO,      DSLINKASSINAT,      NRANEXO,
                DSPATH,             DTTRANSMISSAO,      DTASSINATURA,
                IDATIVO,            DTINCLUSAO,         DTULTATU,
                NRORGINCLUSAO,      CDOPERINCLUSAO,     NRORGULTATU,
                CDOPERULTATU,       DTREJEICAO,         DSREJEICAO,
                DSCHAVEDOCUMENTO,   NMDOCUMENTO,        IDTIPOASSINATURA,
                NRIDSIGNATARIO,     NMFILE
            ) VALUES (
                :NRORG,             :NRINTELETRDIGIT,   :NRPARCNEGOCIO,
                :NRTIPODOCUMENTO,   :NRCATEGDOCUMENTO,  :IDSTATUS,
                :DSIDDOCUMENTO,     :DSLINKASSINAT,     :NRANEXO,
                :DSPATH,            :DTTRANSMISSAO,     :DTASSINATURA,
                :IDATIVO,           :DTINCLUSAO,        :DTULTATU,
                :NRORGINCLUSAO,     :CDOPERINCLUSAO,    :NRORGULTATU,
                :CDOPERULTATU,      :DTREJEICAO,        :DSREJEICAO,
                :DSCHAVEDOCUMENTO,  :NMDOCUMENTO,       :IDTIPOASSINATURA,
                :NRIDSIGNATARIO,    :NMFILE
            )
SQL;

        $stmt = $this->connection->prepare($sql);
        $stmt->execute($params);
    }
}